@@ -16,7 +16,7 @@ try:
 except ModuleNotFoundError:
     pass
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 __release__ = 20230205
 
 
@@ -52,16 +52,16 @@ def lis2frame(path: str, use_simpandas=False, raise_error=True):
                                           frames[l_count]['header']['name']
                                           if frames[l_count]['header']['name'] is not None
                                              and len(frames[l_count]['header']['name']) > 0 else None),
-                                    meta=_make_header(l_count=l_count, i=i),
+                                    meta=_make_header(l_count=l_count, i=i, sr=sr),
                                     source=path)
         else:
             return data.set_index(index_name)
 
 
-    def _make_header(l_count, i):
+    def _make_header(l_count, i, sr):
         to_concat = []
-        if 'curves_units' in frames[l_count][i]:
-            to_concat.append(pd.DataFrame(frames[l_count][i]['curves_units'][sample_rate],
+        if 'curves_units' in frames[l_count][i] and sr in frames[l_count][i]['curves_units']:
+            to_concat.append(pd.DataFrame(frames[l_count][i]['curves_units'][sr],
                                           index=['units']).transpose())
         if 'wellsite_data' in frames[l_count][i]:
             to_concat.append(pd.DataFrame(frames[l_count][i]['wellsite_data']).set_index('MNEM'))
@@ -131,7 +131,7 @@ def lis2frame(path: str, use_simpandas=False, raise_error=True):
                                                  'sample_rate': [sr] * len(frames[l_count][i]['curves'][sr])}),
                                    _try_frame(frames[l_count][i]['curves'][sr])], axis=1),
                         l_count=l_count, i=i, sr=sr),
-        header=_make_header(l_count=l_count, i=i),
+        header=_make_header(l_count=l_count, i=i, sr=sr),
         units=pd.Series(frames[l_count][i]['curves_units'][sr]),
         source=path,
         well=(
